#
# spec file for package talloc-man
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?py3_soflags:  %global py3_soflags cpython-%{python3_version_nodots}m}
%{!?py3_soflags_dash:   %global py3_soflags_dash %(echo %{py3_soflags} | sed "s/_/-/g")}
%{!?py3_incdir:  %global py3_incdir %(%{__python3} -c "import sysconfig as s; print(s.get_path('include'))")}
%define build_man 1

%if %{build_man}
Name:           talloc-man
BuildRequires:  doxygen
%else
Name:           talloc
BuildRequires:  autoconf
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt
BuildRequires:  pkg-config
BuildRequires:  python3-base
BuildRequires:  python3-devel
#!BuildIgnore:  python
%endif # build_man
URL:            http://talloc.samba.org/
Version:        2.4.1
Release:        1.1
Summary:        Samba talloc Library
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Source:         https://download.samba.org/pub/talloc/talloc-%{version}.tar.gz
Source1:        https://download.samba.org/pub/talloc/talloc-%{version}.tar.asc
Source4:        baselibs.conf
Patch0:         talloc-python3.5-fix-soabi_name.patch
# Originally from https://git.samba.org/samba.git/?p=samba.git;a=patch;h=aabdcc91513e242c4f191e1bbbb70c890416d213
Source50:       talloc.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Talloc is a hierarchical, reference counted memory pool system with
destructors.

It is the core memory allocator used in Samba.

%if ! %{build_man}

%package -n libtalloc2
Summary:        Samba talloc library
Group:          System/Libraries
Provides:       bundled(libreplace)

%description -n libtalloc2
Talloc is a hierarchical, reference counted memory pool system with
destructors.

It is the core memory allocator used in Samba.

This package includes the talloc2 library.

%package -n libtalloc-devel
Summary:        Libraries and Header Files to Develop Programs with talloc2 Support
# Man pages are built in a 2nd spec file in order to break a build cycle with doxygen->cmake->krb5->libtalloc
Group:          Development/Libraries/C and C++
%if 0%{?suse_version} > 1030
Recommends:     %{name}-man
%endif
Requires:       libtalloc2 = %{version}
Requires:       pkg-config

%description -n libtalloc-devel
Talloc is a hierarchical, reference counted memory pool system with
destructors.

It is the core memory allocator used in Samba.

Libraries and Header Files to Develop Programs with talloc2 Support.

%package -n python3-talloc
Summary:        Python3 bindings for the Talloc library
Group:          Development/Libraries/Python
Requires:       libtalloc2 = %{version}
Obsoletes:      python-talloc

%description -n python3-talloc
This package contains the Python3 bindings for the Talloc library.

%package -n python3-talloc-devel
Summary:        Developer tools for the Talloc library
Group:          Development/Libraries/Python
Requires:       pkg-config
Requires:       python3-talloc = %{version}
Obsoletes:      python-talloc-devel

%description -n python3-talloc-devel
Libraries and Header Files to Develop Programs with python3-talloc Support

%endif # ! build_man

%prep
%setup -n talloc-%{version} -q
%autopatch -p1

%build
%if ! %{build_man}
export CFLAGS="%{optflags} -D_GNU_SOURCE -D_LARGEFILE64_SOURCE -DIDMAP_RID_SUPPORT_TRUSTED_DOMAINS"
CONFIGURE_OPTIONS="\
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--disable-rpath \
	--disable-rpath-install \
	--disable-silent-rules \
	--bundled-libraries=NONE \
	--builtin-libraries=replace \
"
./configure ${CONFIGURE_OPTIONS}
make %{?_smp_mflags} \
	all

%else

doxygen doxy.config

%endif # ! build_man

%if ! %{build_man}
%check
%if 0%{?suse_version} != 1110 || "%{_build_arch}" == "x86_64"
%if "%{qemu_user_space_build}" == "1"
echo "skipping test on qemu userspace build due to AT_RANDOM not changing"
%else # qemu_user_space_build == 1
mkdir lib/talloc
ln test_magic_differs* lib/talloc/
LD_LIBRARY_PATH=bin/shared make test
%endif # qemu_user_space_build == 1
%endif # suse_version != 1110; fails for i586 and ppc64
%endif # ! build_man

%install
%if ! %{build_man}
%make_install
rm -r "%{buildroot}/%{_mandir}"
mkdir -p %{buildroot}/%{py3_incdir}
mv %{buildroot}/%{_includedir}/pytalloc.h %{buildroot}/%{py3_incdir}/pytalloc.h
sed -i 's;${prefix}/include;%{py3_incdir};g' %{buildroot}/%{_libdir}/pkgconfig/pytalloc-util.%{py3_soflags}.pc
sed -i 's;-lpytalloc-util.%{py3_soflags_dash};-lpytalloc-util.%{py3_soflags};g' %{buildroot}/%{_libdir}/pkgconfig/pytalloc-util.%{py3_soflags}.pc
%else

# Install API documentation
mkdir -p "%{buildroot}/%{_mandir}"
cp -a doc/man/* "%{buildroot}/%{_mandir}/"

%endif  # ! build_man

%if ! %{build_man}
%post -n libtalloc2 -p /sbin/ldconfig

%postun -n libtalloc2 -p /sbin/ldconfig

%post -n python3-talloc -p /sbin/ldconfig

%postun -n python3-talloc -p /sbin/ldconfig

%files -n libtalloc2
%defattr(-,root,root)
%{_libdir}/libtalloc.so.*

%files -n libtalloc-devel
%defattr(-,root,root)
%{_includedir}/talloc.h
%{_libdir}/libtalloc.so
%{_libdir}/pkgconfig/talloc.pc

%files -n python3-talloc
%defattr(-,root,root)
%{_libdir}/libpytalloc-util.%{py3_soflags}.so.*
%{python3_sitearch}/talloc.%{py3_soflags}.so

%files -n python3-talloc-devel
%defattr(-,root,root)
%{py3_incdir}/pytalloc.h
%{_libdir}/pkgconfig/pytalloc-util.%{py3_soflags}.pc
%{_libdir}/libpytalloc-util.%{py3_soflags}.so

%else

%files
%defattr(-,root,root)
%{_mandir}/man3/libtalloc*.3.*
%{_mandir}/man3/talloc*.3.*

%endif # ! build_man

%changelog
* Tue Sep 26 2023 Noel Power <nopower@suse.com>
-  Update to 2.4.1
  * Remove remaining, but broken python2 support
  * Spelling fixes
  * Remove unneeded va_copy()
* Fri Mar 17 2023 Samuel Cabrero <scabrero@suse.de>
- Update to 2.4.0
  * Add talloc_asprintf_addbuf()
  * Support python 3.12
* Thu Sep 22 2022 Noel Power <nopower@suse.com>
- Update to 2.3.4
  + configure/Makefile: export PYTHONHASHSEED=1 in all
    'configure/Makefile' scripts
  + lib:replace: Reformat shell script
  + nsswitch: reduce dependecies to private libraries and link
    static/builtin if possible
* Fri Sep 17 2021 Samuel Cabrero <scabrero@suse.de>
- Update to 2.3.3
  + python: Ensure reference counts are properly incremented
  + Change pytalloc source to LGPL;(bso#9931);
* Wed Mar 31 2021 Samuel Cabrero <scabrero@suse.de>
- Update to 2.3.2
* Mon Oct 12 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.16:
  bad %%if condition:  01550 != 1110 || "x86_64" == x86_64
  no bare word support, x86_64 needs to be quoted
* Fri Mar  6 2020 Noel Power <nopower@suse.com>
- Upgrade to 2.3.1
  + Upgrade waf to 2.0.18 to fix a cross-compilation issue;
    (bso#13846).
  + lib/talloc: clang: Fix 'Value stored during its initialization
    is never read'.
  + Spelling fixes s/recieved/received/
  + talloc: ASAN fix for test_magic_protection.
  +  talloc: ASAN fix for test_rusty
  +  talloc: ASAN fix for test_pool_nest
  +  talloc: ASAN fix for test_talloc_free_in_destructor
  +  talloc: ASAN fix for test_realloc_on_destructor_parent
* Tue Nov 26 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 2.3.0.
- Patches waf_upgrade.patch and waf_use_native_waf_timer.patch
  are no needed anymore. They are subsumed by the upstream
  tarball.
* Mon Oct 21 2019 Matej Cepl <mcepl@suse.com>
- Add two patches making build compatible with Python 3.8.0:
  - waf_upgrade.patch
  - waf_use_native_waf_timer.patch
* Thu Oct  3 2019 James McDonough <jmcdonough@suse.com>
- Update to version 2.2.0
  + Remove pytalloc_CObject_FromTallocPtr()
  + Remove --extra-python (a build time mode to produce Python2 and Python3
    bindings at the same time)
  + New minor version to allow Samba 4.10 to release a talloc if
    required from that branch
* Tue Mar  5 2019 dmulder@suse.com
- Update to version 2.1.16
  + Fix standalone build of talloc.
* Wed Feb  6 2019 dmulder@suse.com
- Update to version 2.1.15
  + Deprecate talloc_set_memlimit() and talloc_autofree_context()
  + Fix undefined behavior in talloc_memdup
  + The build uses python3 by default:
  + --extra-python would take python2 now
  + To build with python2 only use:
    PYTHON=python2 ./configure
    PYTHON=python2 make
    PYTHON=python2 make install
* Wed Aug  8 2018 dmulder@suse.com
- Update to version 2.1.14
  + Fix some typos in the comments
  + Remove extra 0x prefix for the "%%p" format specifiers,
    avoiding 0x0x0 strings in the output.
  + make sure we link extra-python versions of libraries
* Thu Apr  5 2018 jmcdonough@suse.com
- Update to version 2.1.13
  + Use atexit() again instead of a library destructor; (bso#13366);
    (bso#7587).
  + Prevent assert in sssd (bso#7587).
* Tue Mar 27 2018 dimstar@opensuse.org
- Eliminate usage of %%__cp and %%__mkdir_p.
* Fri Mar 16 2018 jmcdonough@suse.com
- Update to version 2.1.11
  + disable-python - fix talloc wscript if bundling disabled
  + Do not disclose the random talloc magic in free()'ed memory
* Mon Oct  9 2017 jmcdonough@suse.com
- Reference library name directly instead of using variables to
  pass obs source validator.
* Mon Oct  2 2017 jengelh@inai.de
- Remove %%if guards for blocks that do not affect the build result.
  Fix RPM groups and summaries. Drop very old SUSE support.
  Replace old RPM macros by new constructs.
* Wed Jul 26 2017 scabrero@suse.com
- Update to version 2.1.10
  + build, documentation and python3 improvements
  + delete sle11-remove-unknown-compiler-options.patch, supported
    options are checked for in upstream code
* Thu Mar 23 2017 jmcdonough@suse.com
- sle11-remove-unknown-compiler-options.patch: build SLE11 and earlier
  without -Wno-format-length.
* Wed Mar 22 2017 jmcdonough@suse.com
- Update to version 2.1.9; (bsc#1032915).
  + fix some coverity defects
  + fix TALLOC_VERSION_MINOR and talloc_version_minor()
  + add new tests
  + add pytalloc_get_type()
  + add pytalloc_GenericObject_{steal,reference}[_ex]()
* Wed Sep 14 2016 jmcdonough@suse.com
- Update to version 2.1.8.
  + performance improvements
  + Fix memory leak when destructors reparent children; (bso#11901).
* Tue Mar 15 2016 lmuelle@suse.com
- Update to 2.1.6; (bsc#954658).
  + pytalloc: Add new BaseObject
  + pytalloc: add a _pytalloc_get_type() helper function and generate
    PyExc_TypeError on mismatch
  + talloc: add _pytalloc_get_ptr/_pytalloc_get_mem_ctx helper functions
  + Improve testsuite by avoiding path issues
  + Only set public headers field when installing as a public library
  + Fix a documentation typo
* Mon Mar  7 2016 toddrme2178@gmail.com
- Add talloc-python3.5-fix-soabi_name.patch: Do not change x86_64 to
  x86-64 when building with python 3.5.
* Sun Feb 21 2016 lmuelle@suse.com
- Avoid a file collision for non SUSE build targets; (bsc#966174).
* Fri Feb 12 2016 lmuelle@suse.com
- Provide python-talloc and python-talloc-devel; (bsc#966523).
* Wed Nov 11 2015 lmuelle@suse.com
- Update to 2.1.5; (bsc#954658).
  + Minor build fixes
* Sun Nov  8 2015 lmuelle@suse.com
- Point LD_LIBRARY_PATH to the just-built libraries while calling make test.
- Create a 2nd talloc-man spec-file to avoid a build cycle.
- Recommend to install talloc-man from libtalloc-devel.
* Fri Oct 30 2015 lmuelle@suse.com
- Add doxygen at build time to add the development documentation.
- Disable rpath-install and silent-rules while configure.
* Sat Oct 24 2015 lmuelle@suse.com
- Add python3-talloc and python3-talloc-devel; (bsc#951911).
* Thu Oct 22 2015 lmuelle@suse.com
- Rename pytalloc to python-talloc.
* Thu Oct 22 2015 lmuelle@suse.com
- Update to 2.1.4; (bsc#951660).
  + Test that talloc magic differs between processes.
  + Increment minor version due to added talloc_test_get_magic.
  + Provide tests access to talloc_magic.
  + Test magic protection measures.
* Mon Sep  7 2015 lmuelle@suse.com
- Update the Samba Library Distribution Key file 'talloc.keyring';
  (bso#945116).
* Wed Jul 22 2015 lmuelle@suse.com
- Update to 2.1.3; (bsc#939051).
  + improved python3 bindings
  + documentation fixes regarding talloc_reference() and talloc_unlink()
* Thu Apr 16 2015 lmuelle@suse.com
- Update to 2.1.2.
  + Fix memory leak in SMB2 notify handling; (bso#11144).
  + fix _talloc_total_limit_size prototype
  + build: improve detection of srcdir
* Thu Nov  6 2014 lmuelle@suse.com
- Use the upstream tar ball, as signature verification is now able to handle
  compressed archives.
* Fri May 23 2014 lmuelle@suse.com
- Require pkg-config from the devel packages.
* Thu May 22 2014 lmuelle@suse.com
- Update to 2.1.1.
  + documentation updates
  + a fix for pytalloc-util.pc
  + performance improvements here and there
  + fixed compiler warnings
* Tue May 20 2014 dmueller@suse.com
- Remove dependency on doxygen. Doxygen is only used for generating
  the html documentation, but the html documentation was not
  actually packaged, so there is no point in running it.
* Wed Apr 23 2014 dmueller@suse.com
- Remove dependency on gpg-offline to reduce rebuild times; signature checking
  is implemented already in the source validator.
* Fri Dec  6 2013 lmuelle@suse.com
- Update to 2.1.0.
  + Add talloc_pooled_object and test it
  + Allow nested pools
  + Add a separate pool size
  + Put pool-specific data before the chunk
  + Introduce __talloc_with_prefix
  + Decouple the dual use of chunk->pool
  + Only provide the --enable-talloc-compat1 in standalone build
  + Simplify _talloc_free_poolmem a bit
* Fri Dec  6 2013 lmuelle@suse.com
- Verify source tar ball gpg signature.
* Thu Aug 29 2013 lmuelle@suse.com
- PreReq /sbin/ldconfig from pytalloc.
* Wed Aug 28 2013 lmuelle@suse.com
- Add pytalloc to baselibs.conf.
* Mon Jul 22 2013 lmuelle@suse.com
- BuildIgnore python for post-11.0 systems only.
- Package the talloc man page only on post-11.0 systems.
* Sun Jul  7 2013 coolo@suse.com
- BuildIgnore python to avoid build cycle
* Sun Dec  2 2012 lmuelle@suse.com
- Update to 2.0.8.
  + Convert error cecking macros into fns
  + don't allow a talloc_pool inside a talloc_pool.
  + use a struct for pool headers.
  + remove unused variables
  + Update doxygen config.
  + Slightly simplify talloc_unlink
  + Only check for pkg-config file when checking for system talloc.
  + fix a comment typo
  + simplifiy the logic to build talloc_testsuite in the standalone build
* Thu Jun 28 2012 lmuelle@suse.com
- Disable rpath while configure.
* Tue Jun 12 2012 lmuelle@suse.com
- Add missing group field to the library subpackage.
* Sun Jun  3 2012 lmuelle@suse.com
- Define library name and use it instead of libtalloc2.
* Sat Jun  2 2012 lmuelle@suse.com
- Rename package to talloc and add an independent libtalloc2 subpackage.
- Enhance and polish the package descriptions and summaries.
* Thu May 31 2012 lmuelle@suse.com
- BuildRequire pkg-config for post-10.2 systems and else pkgconfig.
* Thu May 31 2012 lmuelle@suse.com
- Rename libtalloc2-devel to libtalloc-devel.
* Wed May 30 2012 lmuelle@suse.com
- Define python_sitearch if undefined.
* Wed May 30 2012 lmuelle@suse.com
- Remove superfluous AutoReqProv on line.
* Wed May 16 2012 lmuelle@suse.com
- Require libtalloc2 from libtalloc2-devel.
* Wed May 16 2012 lmuelle@suse.com
- Cleanup BuildRequires and spec file in general.
- Add new pytalloc and pytalloc-devel sub packages.
* Wed Sep  7 2011 lars@samba.org
- Initial independent libtalloc2 package.
